changeset 10338:67db2cbc0294

[gaim-migrate @ 11546] Eagle-Eye McGraw (aka Kevin) caught this committer: Tailor Script <tailor@pidgin.im>
author Mark Doliner <mark@kingant.net>
date Thu, 09 Dec 2004 04:32:25 +0000
parents 682201b69107
children 3eb03f22e082
files plugins/win32/transparency/win2ktrans.c
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/plugins/win32/transparency/win2ktrans.c	Thu Dec 09 03:55:19 2004 +0000
+++ b/plugins/win32/transparency/win2ktrans.c	Thu Dec 09 04:32:25 2004 +0000
@@ -448,9 +448,9 @@
 
 	gtk_box_pack_start(GTK_BOX(trans_box), hbox, FALSE, FALSE, 5);
 
 	/* If this version of Windows dosn't support Transparency, grey out options */
 	if(!has_transparency()) {
-		gaim_debug_warning(WINTRANS_PLUGIN_ID, "This version of windows dosn't support transparency\n");
+		gaim_debug_warning(WINTRANS_PLUGIN_ID, "This version of Windows doesn't support transparency\n");
 		gtk_widget_set_sensitive(GTK_WIDGET(imtransbox), FALSE);
 		gtk_widget_set_sensitive(GTK_WIDGET(button), FALSE);
 		gtk_widget_set_sensitive(GTK_WIDGET(trans_box), FALSE);
@@ -448,9 +448,9 @@
 	gtk_box_pack_start(GTK_BOX(trans_box), hbox, FALSE, FALSE, 5);
 
-	/* If this version of Windows dosn't support Transparency, grey out options */
+	/* If this version of Windows doesn't support Transparency, grey out options */
 	if(!has_transparency()) {